@@ -1,6 +1,6 @@
 package App::PerlWatcher::Watcher;
 {
-  $App::PerlWatcher::Watcher::VERSION = '0.14_01';
+  $App::PerlWatcher::Watcher::VERSION = '0.16_3';
 }
 # ABSTRACT: Observes some external source of events and emits the result of polling them
 
@@ -12,6 +12,7 @@ use App::PerlWatcher::Levels;
 use App::PerlWatcher::Status;
 use aliased 'App::PerlWatcher::WatcherMemory';
 use Carp;
+use Data::Dump::Filtered qw/dump_filtered/;
 use Devel::Comments;
 use Digest::MD5 qw(md5_base64);
 use List::Util qw( max );
@@ -19,8 +20,7 @@ use Storable qw/freeze/;
 
 use Moo::Role;
 
-
-requires 'description';
+with qw/App::PerlWatcher::Describable/;
 
 
 has 'engine_config'     => ( is => 'ro', required => 1);
@@ -38,7 +38,13 @@ has 'unique_id'         => ( is => 'lazy');
 has 'memory'            => ( is => 'rw');
 
 
-has 'callback'          => ( is => 'rw');
+has 'callback'          => ( is => 'rw', required => 1);
+
+
+has 'watcher_guard'     => ( is => 'rw');
+
+
+requires 'build_watcher_guard';
 
 use overload fallback => 1, q/""/ => sub { $_[0]->unique_id; };
 
@@ -71,27 +77,57 @@ sub _build_memory {
 sub _build_unique_id {
     my $self = shift;
     my $class = ref($self);
-    my $config = $self->config;
-    my @clean_keys = grep { (ref($config->{$_}) // '?') ne 'CODE' }
-        keys %$config;
-    my @values = sort @{ $config }{ @clean_keys };
-    my $hash = md5_base64(freeze(\@values));
+    # Filter strips down the subroutine references
+    # and transforms hashes to arrays sorted by keys.
+    # this is needed to always have the same string
+    # for the same config, any change will lead
+    # to change of md5, and the id will be different.
+    my $filter; $filter = sub {
+        my($ctx, $object_ref) = @_;
+        my $ref_type = ref($object_ref);
+        return { object => 'FILTERED' } if ($ref_type eq 'CODE');
+        return undef                    if ($ref_type ne 'HASH');
+        my @determined_array =
+            map {
+                my $stringized_value = dump_filtered($object_ref->{$_}, $filter);
+                my $value = eval $stringized_value;
+                ($_ => $value);
+            } sort keys %$object_ref;
+        return { dump => dump_filtered(\@determined_array, $filter) };
+    };
+    my $dumped_config = dump_filtered($self->config, $filter);
+    my $hash = md5_base64($dumped_config);
     my $id = "$class/$hash";
-    ## @values
-    ## $id
+}
+
+
+sub force_poll {
+    my $self = shift;
+    $self->active(0);
+    $self->active(1);
 }
 
 
 sub active {
     my ( $self, $value ) = @_;
     if ( defined($value) ) {
-        delete $self->{_w} unless $value;
+        $self->memory->active($value);
+        $self->watcher_guard(undef)
+            unless $value;
         $self->start if $value;
     }
-    return defined( $self->{_w} );
+    return $self->memory->active;
 }
 
 
+sub start {
+    my $self = shift;
+    $self->watcher_guard( $self->build_watcher_guard )
+        if $self->memory->active;
+}
+
+
+
 sub calculate_threshods {
     my ($l, $r) = @_;
     my $thresholds_map;
@@ -175,7 +211,7 @@ sub _emit_event {
     my $status = App::PerlWatcher::Status->new(
         watcher     => $self,
         level       => $level,
-        description => sub {  $self->description  },
+        description => sub { $self->describe },
         items       => $items,
     );
     $callback->($status);
@@ -212,7 +248,7 @@ App::PerlWatcher::Watcher - Observes some external source of events and emits th
 
 =head1 VERSION
 
-version 0.14_01
+version 0.16_3
 
 =head1 ATTRIBUTES
 
@@ -248,16 +284,30 @@ and unique_id are stored.
 The subroutine reference, which is been called on every poll of watcher external source.
 It's argument is the State.
 
+=head2 watcher_guard
+
+The watcher guard returned by AnyEvent->io, AnyEvent->timer etc, with is an core
+under wich the Watcher is been build.
+
 =head1 METHODS
 
-=head2 description
+=head2 build_watcher_guard
 
-The string description of the watcher
+The method is responsible for building watcher_guard
+
+=head2 force_poll
+
+Immediatly polls the watched object.
 
 =head2 active
 
 Turns on and off the wacher.
 
+=head2 start
+
+Starts the watcher, which will emit it's statuses. The watcher will
+start only it is active.
+
 =head2 calculate_threshods
 
 Calculates the thresholds_map based on the left map and righ map
