@@ -1,6 +1,6 @@
 package App::PerlWatcher::Watcher::HTTPSimple;
 {
-  $App::PerlWatcher::Watcher::HTTPSimple::VERSION = '0.14_01';
+  $App::PerlWatcher::Watcher::HTTPSimple::VERSION = '0.16_3';
 }
 # ABSTRACT: The simple HTTP watcher, where actual http responce body is been processed by closure
 
@@ -15,6 +15,7 @@ use Moo;
 use URI;
 
 
+
 has 'url'                   => ( is => 'ro', required => 1);
 
 
@@ -61,7 +62,28 @@ App::PerlWatcher::Watcher::HTTPSimple - The simple HTTP watcher, where actual ht
 
 =head1 VERSION
 
-version 0.14_01
+version 0.16_3
+
+=head1 SYNOPSIS
+
+ # use the following config for Engine:
+
+ {
+   class => 'App::PerlWatcher::Watcher::HTTPSimple',
+   config => {
+     url                 =>  'http://download.finance.yahoo.com/d/quotes.csv?s=EURUSD=X&f=sl1d1t1c1ohgv&e=.csv',
+     title               =>  '€/$',
+     frequency           => 600,
+     timeout             => 10,
+     response_handler    => sub {
+        (split(',', $_))[1];
+     },
+     on                  => {
+        ok      => { 1  => 'notice' },
+        fail    => { 10 => 'info'   },
+     },
+    },
+ },
 
 =head1 ATTRIBUTES
 
