@@ -1,6 +1,6 @@
 package App::PerlWatcher::Watcher::Weather;
 {
-  $App::PerlWatcher::Watcher::Weather::VERSION = '0.14_01';
+  $App::PerlWatcher::Watcher::Weather::VERSION = '0.16_3';
 }
 # ABSTRACT: Weather watches based around api.yr.no. Currenlty monitors only temperature and does no any notifications / level alerts.
 
@@ -21,6 +21,7 @@ our $T_UNITS = {
 };
 
 
+
 has 'latitude'          => ( is => 'ro', required => 1);
 
 
@@ -48,7 +49,7 @@ sub _build_url {
 
 sub description {
     my $self = shift;
-    my $desc = "Weather ";
+    my $desc = "";
     my %data = %{ $self->data // {} };
     if ( %data ) {
         $desc .= join(q{, } ,
@@ -90,7 +91,21 @@ App::PerlWatcher::Watcher::Weather - Weather watches based around api.yr.no. Cur
 
 =head1 VERSION
 
-version 0.14_01
+version 0.16_3
+
+=head1 SYNOPSIS
+
+ # use the following config for Engine:
+        {
+            class => 'App::PerlWatcher::Watcher::Weather',
+            config => {
+                describer   => sub { "Weather in Minsk: " . $_[0] },
+                latitude    => 53.54,
+                longitude   => 27.34,
+                frequency   => 1800,
+                timeout     => 15,
+            },
+        },
 
 =head1 ATTRIBUTES
 
