@@ -1,6 +1,6 @@
 package App::PerlWatcher::WatcherMemory;
 {
-  $App::PerlWatcher::WatcherMemory::VERSION = '0.14_01';
+  $App::PerlWatcher::WatcherMemory::VERSION = '0.16_3';
 }
 # ABSTRACT: Represents watcher memory, which can be persisted (detached) from Watcher
 
@@ -21,6 +21,9 @@ has 'thresholds_map'    => ( is => 'ro', required => 1);
 has 'last_level'        => ( is => 'rw', default => sub { LEVEL_NOTICE; } );
 
 
+has 'active' => (is => 'rw', default => sub { 1 } );
+
+
 sub interpret_result {
     my ($self, $result) = @_;
     my $threshold_map = $self -> thresholds_map;
@@ -65,7 +68,7 @@ App::PerlWatcher::WatcherMemory - Represents watcher memory, which can be persis
 
 =head1 VERSION
 
-version 0.14_01
+version 0.16_3
 
 =head1 ATTRIBUTES
 
@@ -86,6 +89,10 @@ which level of severity it is. It looks like:
 
 Represents last emitted watcher level. 
 
+=head2 active
+
+Represents whether the watcher is active or not
+
 =head1 METHODS
 
 =head2 interpret_result
